@@ -17,7 +17,7 @@ py::list to_python_list(std::list<T> std_list) {
     return python_list;
 }
 
-std::list<midi_generator::Note> midi_generator::generate() {
+std::list<midi_generator::Note> midi_generator::generate(const midi_generator::Configuration& config) {
     try {
         py::module_ commands = py::module_::import("midi_generator.commands");
         py::object result = commands.attr("generate")();
@@ -28,7 +28,7 @@ std::list<midi_generator::Note> midi_generator::generate() {
                     obj.attr("velocity").cast<int>(),
                     obj.attr("start").cast<double>(),
                     obj.attr("end").cast<double>()
-                    );
+            );
 
         return notes;
     } catch (py::error_already_set &error) {
@@ -36,6 +36,9 @@ std::list<midi_generator::Note> midi_generator::generate() {
         return {};
     }
 }
+std::list<midi_generator::Note> midi_generator::generate() {
+    return midi_generator::generate(Configuration{});
+}
 
 std::list<midi_generator::Note> midi_generator::mutate(std::list<midi_generator::Note> notes) {
     try {
